@@ -307,6 +307,18 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
+    @keyword(tags=("PageContent",))
+    def record_selector(self):
+        """
+        Record the selector that is under mouse.
+        Focus on the page and move mouse over the element you want to select.
+        Press 's' to store the elements selector.
+        """
+        with self.playwright.grpc_channel() as stub:
+            response = stub.RecordSelector(Request.Empty())
+            logger.info(f"Selector: {response.result}")
+            return json.loads(response.result)
+
     @keyword(tags=("Setter", "PageContent"))
     def hover(
         self,
